ManualAdapter class
Adapter for apps using a custom localization setup.
- Inheritance
-
- Object
- ChangeNotifier
- SwayLocaleAdapter
- ManualAdapter
Constructors
-
ManualAdapter({required List<
Locale> supportedLocales, required Locale currentLocale, required void onLocaleChange(Locale locale)}) - Creates a ManualAdapter.
Properties
- currentLocale → Locale
-
Returns the currently active locale.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- onLocaleChange → void Function(Locale locale)
-
Callback to set the locale.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedLocales
→ List<
Locale> -
Returns the list of locales the app supports.
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setLocale(
Locale locale) → void -
Sets the active locale, triggering a rebuild if necessary.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited