Sway class
Namespace for Sway convenience APIs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
debugOverlay(
{Key? key, required Widget child, Listenable? localeListenable, Locale getLocale()?, void setLocale(Locale locale)?, List< Locale> ? supportedLocales, SwayLocaleAdapter? adapter, bool enabled = true, bool enableInRelease = false, bool debugOnly = false, bool disabled = false}) → Widget - One-liner for production shells: nest an Overlay, bridge a listenable locale owner, and show the debug bubble.