SwayLocaleMeta class
Metadata about a locale used by the overlay and codegen.
Constructors
- SwayLocaleMeta({required String languageCode, required bool isRtl, required String displayName})
-
Creates a SwayLocaleMeta.
const
- SwayLocaleMeta.fromLanguageCode(String languageCode, {String? displayName})
-
Creates metadata from a language code, auto-detecting RTL.
factory
Properties
- displayName → String
-
Human-readable display name for the locale.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isRtl → bool
-
Whether this locale is RTL.
final
- languageCode → String
-
The language code (e.g.
en,ar,pt_BR).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override